function pyra = scaleSpace(im, interval, minSize)
% Record the size of the image
pyra.size = size(im);

% Precompute how many scales and steps you need
im = imresize(im, 2);
smallDim = min(size(im, 1), size(im,2));
numOctaves = ceil(log(smallDim/minSize))+1;

% Allocate space for the images
pyra.im = cell(1, numOctaves*interval);
pyra.scale = zeros(1, numOctaves*interval);

% Loop over scales and compute pyramid representation
stepSize = 2^(1/interval);
currScale = 2;
offset = 0;
for s = 1:numOctaves, 
    for i = 1:interval,
        pyra.im{offset+i} = imresize(im, 1/stepSize^(i-1),'bilinear');
        pyra.scale(offset+i) = currScale/stepSize^(i-1);
    end
    im = imresize(im, 0.5);
    currScale = currScale*0.5;
    offset = offset + interval;
end